LeftRightContainerStyle class
Constructors
- LeftRightContainerStyle({Color? startBackgroundColor, Color? endBackgroundColor, Color? backgroundColor, EdgeInsets startPadding = const EdgeInsets.all(5), EdgeInsets endPadding = const EdgeInsets.all(5), Color? arrowButtonBackgroundColor, Color? arrowIconColor, double arrowWidth = 20, double arrowHeight = 30, BorderRadius? arrowBorderRadius, Duration animationDuration = const Duration(milliseconds: 250), Curve animationCurve = Curves.fastOutSlowIn})
-
const
Properties
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- arrowBorderRadius → BorderRadius?
-
final
- arrowButtonBackgroundColor → Color?
-
final
- arrowHeight → double
-
final
- arrowIconColor → Color?
-
final
- arrowWidth → double
-
final
- backgroundColor → Color?
-
final
- endBackgroundColor → Color?
-
final
- endPadding → EdgeInsets
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startBackgroundColor → Color?
-
final
- startPadding → EdgeInsets
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited